==> proshade-0.7.5.1.tar.gz: proshade-0.7.5.1/proshade/documentation/html/_pro_s_h_a_d_e__symmetry_8hpp.js <==
var _pro_s_h_a_d_e__symmetry_8hpp =
[
    [ "addAxisUnlessSame", "_pro_s_h_a_d_e__symmetry_8hpp.html#ad56b16f741c8701d43f8f74899c8ab2c", null ],
    [ "addZeroPeakToGroups", "_pro_s_h_a_d_e__symmetry_8hpp.html#ade9b717260e86c8f24bcbe6d17fe4e06", null ],
    [ "checkExpectedAgainstFound", "_pro_s_h_a_d_e__symmetry_8hpp.html#a074d9c1d40d7491ea9f9f9639744e18d", null ],
    [ "checkFittingAxisDualAndSave", "_pro_s_h_a_d_e__symmetry_8hpp.html#a210ee0af651d440b68168882ead71c66", null ],
    [ "checkFittingAxisTripleAndSave", "_pro_s_h_a_d_e__symmetry_8hpp.html#a194944b48a4b6b523ef251a2a03eab17", null ],
    [ "checkForMissingPeak", "_pro_s_h_a_d_e__symmetry_8hpp.html#aacced7feb8ce5251dce199505912d997", null ],
    [ "completeMissingCSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#a3008592c3ce58393395e03dac26c3626", null ],
    [ "detectIcosahedralSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#a4f09b90de1f15b345ee7998ff31327f3", null ],
    [ "detectOctahedralSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#a18d456057604616a7cf6b68f59b4f2d0", null ],
    [ "detectTetrahedralSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#a37925ac477480c718451debb01a9c74a", null ],
    [ "determineFoldToTry", "_pro_s_h_a_d_e__symmetry_8hpp.html#ac0a8dc71c37de02256521ebc9178c8d4", null ],
    [ "findExpectedPeakRotations", "_pro_s_h_a_d_e__symmetry_8hpp.html#af4f982fc282e8fca11b6a85f2d2069a5", null ],
    [ "findIcos10C3s", "_pro_s_h_a_d_e__symmetry_8hpp.html#aede68f7d4dd7840b1bfcf8daa3156adf", null ],
    [ "findIcos15C2s", "_pro_s_h_a_d_e__symmetry_8hpp.html#ad0d6480c4de06bce2b7d05c0471eb000", null ],
    [ "findIcos6C5s", "_pro_s_h_a_d_e__symmetry_8hpp.html#a65eb2dbdadc031e511734b5a48e31b08", null ],
    [ "findMissingAxes", "_pro_s_h_a_d_e__symmetry_8hpp.html#af6093da290ce7b73a33e8b55f2c83491", null ],
    [ "findMissingAxesDual", "_pro_s_h_a_d_e__symmetry_8hpp.html#a6d9f533a789bd5c6031fa77b9649ed3d", null ],
    [ "findMissingAxesTriple", "_pro_s_h_a_d_e__symmetry_8hpp.html#ae266053664eb7cf916aa5e2d282e35dd", null ],
    [ "findMissingAxisPoints", "_pro_s_h_a_d_e__symmetry_8hpp.html#a465606e58df7d6a2238d40c6919b2e58", null ],
    [ "findOcta3C4s", "_pro_s_h_a_d_e__symmetry_8hpp.html#aaa63ba6643fd35a6fa67a969ef5e92d9", null ],
    [ "findOcta4C3s", "_pro_s_h_a_d_e__symmetry_8hpp.html#ae003234a38a3abfff24115ee51d99141", null ],
    [ "findOcta6C2s", "_pro_s_h_a_d_e__symmetry_8hpp.html#ae47108b33b0fed84b73fc2d9769d93d1", null ],
    [ "findPeaksByHeightBoundaries", "_pro_s_h_a_d_e__symmetry_8hpp.html#a2137fa16a69fc7a8365439e322b67dc8", null ],
    [ "findPeaksCSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#a648ddad98891a4d8a6af5187d994c5ec", null ],
    [ "findSymmetryUsingFold", "_pro_s_h_a_d_e__symmetry_8hpp.html#ac03088b2929641cd6fc3e2e4e20d874b", null ],
    [ "findTetra3C2s", "_pro_s_h_a_d_e__symmetry_8hpp.html#a193b0307e5bfe47bec26d3867d6750c1", null ],
    [ "findTetra4C3s", "_pro_s_h_a_d_e__symmetry_8hpp.html#ab702e9ca347642df5f49f937000b4184", null ],
    [ "getPeaksAngleAxisPositions", "_pro_s_h_a_d_e__symmetry_8hpp.html#a66b286b7617c645b6543b28c1cd789af", null ],
    [ "giveOppositeAxesSameDirection", "_pro_s_h_a_d_e__symmetry_8hpp.html#a41150b2f8995b2ac1f144143fc83b6ee", null ],
    [ "groupSameAxes", "_pro_s_h_a_d_e__symmetry_8hpp.html#a98538547e5bcc6192bbbea1d7b51c537", null ],
    [ "isSymmetrySame", "_pro_s_h_a_d_e__symmetry_8hpp.html#abb4d85e82d1c55d0aa18795fea449adf", null ],
    [ "missingAxisHeight", "_pro_s_h_a_d_e__symmetry_8hpp.html#ad44ed609e8a3d59674b2b2256aec41f8", null ],
    [ "predictIcosAxes", "_pro_s_h_a_d_e__symmetry_8hpp.html#ad5fcf9bf5ad27ac119d76312b4bcf90b", null ],
    [ "predictOctaAxes", "_pro_s_h_a_d_e__symmetry_8hpp.html#a377aa42d9199d427d93efca48e3cd878", null ],
    [ "printSymmetryCompletion", "_pro_s_h_a_d_e__symmetry_8hpp.html#a9293eec4e7edf274155ed6a07dad8b16", null ],
    [ "printSymmetryGroup", "_pro_s_h_a_d_e__symmetry_8hpp.html#af4b044752fe0a780a3f09743e9d8d58e", null ],
    [ "printSymmetryPeaks", "_pro_s_h_a_d_e__symmetry_8hpp.html#af9835b91e354e4615beb79b5c2a674e9", null ],
    [ "saveAllCSymmetries", "_pro_s_h_a_d_e__symmetry_8hpp.html#a870711ceabba16c8fc79bd93d26b11a8", null ],
    [ "saveDetectedCSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#a5dda335a87d6c26edfd3cf2a29ff7f1f", null ],
    [ "saveDSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#ab0ac919dd609bc6bded806c0f78201fd", null ],
    [ "saveMissingAxisNewOnly", "_pro_s_h_a_d_e__symmetry_8hpp.html#a5dc4353223fc752e0007b2adec193079", null ],
    [ "searchMissingSymmetrySpace", "_pro_s_h_a_d_e__symmetry_8hpp.html#a1ada2416687dbb0bec93603770cb4c83", null ],
    [ "smallestDistanceBetweenAngles", "_pro_s_h_a_d_e__symmetry_8hpp.html#a2b3fcf4dd97e677da27192cf63dbb678", null ],
    [ "sortArrVecHlp", "_pro_s_h_a_d_e__symmetry_8hpp.html#a68d576f90449b7d3fcf5ae4d3114c268", null ],
    [ "testGroupAgainstGroup", "_pro_s_h_a_d_e__symmetry_8hpp.html#a5360c152697780177eb2676888cd5108", null ],
    [ "testGroupAgainstSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#ad8c193e95c7069fafa78dccc1de1aaa4", null ]
];

==> proshade-0.7.5.3.tar.gz: proshade-0.7.5.3/proshade/documentation/html/_pro_s_h_a_d_e__symmetry_8hpp.js <==
var _pro_s_h_a_d_e__symmetry_8hpp =
[
    [ "addAxisUnlessSame", "_pro_s_h_a_d_e__symmetry_8hpp.html#ad56b16f741c8701d43f8f74899c8ab2c", null ],
    [ "addZeroPeakToGroups", "_pro_s_h_a_d_e__symmetry_8hpp.html#ade9b717260e86c8f24bcbe6d17fe4e06", null ],
    [ "checkExpectedAgainstFound", "_pro_s_h_a_d_e__symmetry_8hpp.html#a074d9c1d40d7491ea9f9f9639744e18d", null ],
    [ "checkFittingAxisDualAndSave", "_pro_s_h_a_d_e__symmetry_8hpp.html#a210ee0af651d440b68168882ead71c66", null ],
    [ "checkFittingAxisTripleAndSave", "_pro_s_h_a_d_e__symmetry_8hpp.html#a194944b48a4b6b523ef251a2a03eab17", null ],
    [ "checkForMissingPeak", "_pro_s_h_a_d_e__symmetry_8hpp.html#aacced7feb8ce5251dce199505912d997", null ],
    [ "completeMissingCSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#a3008592c3ce58393395e03dac26c3626", null ],
    [ "detectIcosahedralSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#a4f09b90de1f15b345ee7998ff31327f3", null ],
    [ "detectOctahedralSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#a18d456057604616a7cf6b68f59b4f2d0", null ],
    [ "detectTetrahedralSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#a37925ac477480c718451debb01a9c74a", null ],
    [ "determineFoldToTry", "_pro_s_h_a_d_e__symmetry_8hpp.html#ac0a8dc71c37de02256521ebc9178c8d4", null ],
    [ "findExpectedPeakRotations", "_pro_s_h_a_d_e__symmetry_8hpp.html#af4f982fc282e8fca11b6a85f2d2069a5", null ],
    [ "findIcos10C3s", "_pro_s_h_a_d_e__symmetry_8hpp.html#aede68f7d4dd7840b1bfcf8daa3156adf", null ],
    [ "findIcos15C2s", "_pro_s_h_a_d_e__symmetry_8hpp.html#ad0d6480c4de06bce2b7d05c0471eb000", null ],
    [ "findIcos6C5s", "_pro_s_h_a_d_e__symmetry_8hpp.html#a65eb2dbdadc031e511734b5a48e31b08", null ],
    [ "findMissingAxes", "_pro_s_h_a_d_e__symmetry_8hpp.html#af6093da290ce7b73a33e8b55f2c83491", null ],
    [ "findMissingAxesDual", "_pro_s_h_a_d_e__symmetry_8hpp.html#a6d9f533a789bd5c6031fa77b9649ed3d", null ],
    [ "findMissingAxesTriple", "_pro_s_h_a_d_e__symmetry_8hpp.html#ae266053664eb7cf916aa5e2d282e35dd", null ],
    [ "findMissingAxisPoints", "_pro_s_h_a_d_e__symmetry_8hpp.html#a465606e58df7d6a2238d40c6919b2e58", null ],
    [ "findOcta3C4s", "_pro_s_h_a_d_e__symmetry_8hpp.html#aaa63ba6643fd35a6fa67a969ef5e92d9", null ],
    [ "findOcta4C3s", "_pro_s_h_a_d_e__symmetry_8hpp.html#ae003234a38a3abfff24115ee51d99141", null ],
    [ "findOcta6C2s", "_pro_s_h_a_d_e__symmetry_8hpp.html#ae47108b33b0fed84b73fc2d9769d93d1", null ],
    [ "findPeaksByHeightBoundaries", "_pro_s_h_a_d_e__symmetry_8hpp.html#a2137fa16a69fc7a8365439e322b67dc8", null ],
    [ "findPeaksCSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#a648ddad98891a4d8a6af5187d994c5ec", null ],
    [ "findPredictedAxesHeights", "_pro_s_h_a_d_e__symmetry_8hpp.html#a33c650c19a6954800bba6b3a8f5842e6", null ],
    [ "findSymmetryUsingFold", "_pro_s_h_a_d_e__symmetry_8hpp.html#ac03088b2929641cd6fc3e2e4e20d874b", null ],
    [ "findTetra3C2s", "_pro_s_h_a_d_e__symmetry_8hpp.html#a193b0307e5bfe47bec26d3867d6750c1", null ],
    [ "findTetra4C3s", "_pro_s_h_a_d_e__symmetry_8hpp.html#ab702e9ca347642df5f49f937000b4184", null ],
    [ "getPeaksAngleAxisPositions", "_pro_s_h_a_d_e__symmetry_8hpp.html#a66b286b7617c645b6543b28c1cd789af", null ],
    [ "giveOppositeAxesSameDirection", "_pro_s_h_a_d_e__symmetry_8hpp.html#a41150b2f8995b2ac1f144143fc83b6ee", null ],
    [ "groupSameAxes", "_pro_s_h_a_d_e__symmetry_8hpp.html#a98538547e5bcc6192bbbea1d7b51c537", null ],
    [ "isSymmetrySame", "_pro_s_h_a_d_e__symmetry_8hpp.html#abb4d85e82d1c55d0aa18795fea449adf", null ],
    [ "missingAxisHeight", "_pro_s_h_a_d_e__symmetry_8hpp.html#ad44ed609e8a3d59674b2b2256aec41f8", null ],
    [ "predictIcosAxes", "_pro_s_h_a_d_e__symmetry_8hpp.html#a1ec2a2255f5846b717aebaceb2c1a900", null ],
    [ "predictOctaAxes", "_pro_s_h_a_d_e__symmetry_8hpp.html#a38ce8efbbe05220793b5f01f0fef07a6", null ],
    [ "predictTetraAxes", "_pro_s_h_a_d_e__symmetry_8hpp.html#aef7a2435e9d3616d860aeee2d94dba55", null ],
    [ "printSymmetryCompletion", "_pro_s_h_a_d_e__symmetry_8hpp.html#a9293eec4e7edf274155ed6a07dad8b16", null ],
    [ "printSymmetryGroup", "_pro_s_h_a_d_e__symmetry_8hpp.html#af4b044752fe0a780a3f09743e9d8d58e", null ],
    [ "printSymmetryPeaks", "_pro_s_h_a_d_e__symmetry_8hpp.html#af9835b91e354e4615beb79b5c2a674e9", null ],
    [ "saveAllCSymmetries", "_pro_s_h_a_d_e__symmetry_8hpp.html#a870711ceabba16c8fc79bd93d26b11a8", null ],
    [ "saveDetectedCSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#a5dda335a87d6c26edfd3cf2a29ff7f1f", null ],
    [ "saveDSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#ab0ac919dd609bc6bded806c0f78201fd", null ],
    [ "saveMissingAxisNewOnly", "_pro_s_h_a_d_e__symmetry_8hpp.html#a5dc4353223fc752e0007b2adec193079", null ],
    [ "searchMissingSymmetrySpace", "_pro_s_h_a_d_e__symmetry_8hpp.html#a1ada2416687dbb0bec93603770cb4c83", null ],
    [ "smallestDistanceBetweenAngles", "_pro_s_h_a_d_e__symmetry_8hpp.html#a2b3fcf4dd97e677da27192cf63dbb678", null ],
    [ "sortArrVecHlp", "_pro_s_h_a_d_e__symmetry_8hpp.html#a68d576f90449b7d3fcf5ae4d3114c268", null ],
    [ "testGroupAgainstGroup", "_pro_s_h_a_d_e__symmetry_8hpp.html#a5360c152697780177eb2676888cd5108", null ],
    [ "testGroupAgainstSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#ad8c193e95c7069fafa78dccc1de1aaa4", null ]
];
